# voice-stream: Creating voice bots from LLMs.

[![Poetry](https://img.shields.io/endpoint?url=https://python-poetry.org/badge/v0.json)](https://python-poetry.org/)
[![Tests](https://github.com/DaveDeCaprio/voice-stream/actions/workflows/tests.yaml/badge.svg)](https://github.com/DaveDeCaprio/voice-stream/actions/workflows/tests.yaml)
![Stable Version](https://img.shields.io/pypi/v/voice-stream?label=Stable)
![Python Versions](https://img.shields.io/pypi/pyversions/voice-stream)
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
